# USL_lib_beta

## Introduction

USL_lib_beta is a python package for **ultra-stable laser system** researching, it includings many functions for data deal and calculation, like read TCH data and calculate its PSD and Allan deviation.


## Installation

Install from pypi:

`pip install USL-lib-beta`


## Basic usage

In python:

`import USL_lib_beta as usl`

## Functions

|Function|Description|
|--|--|
|`plot_data_labview()`|Plot the data's gragh from Labview, including the time domain, PSD and Allan Deviation.|